#[macro_use]
extern crate rocket;
use std::sync::atomic::Ordering;

use rocket::serde::json::{json, Json, Value};
use state::State;
use std::thread;

mod gamestate;
mod led;
mod state;

#[post("/gsi", data = "<data>")]
fn gsi(data: Json<gamestate::GamestateData>, gobal_state: &rocket::State<state::State>) -> Value {
    let flashed = match &data.player {
        Some(player) => match &player.state {
            Some(state) => state.flashed,
            None => 0,
        },
        None => 0,
    };

    gobal_state.flashed.store(flashed, Ordering::Relaxed);

    let planted = match &data.round {
        Some(round) => match &round.bomb {
            Some(bomb) => match bomb.as_str() {
                "planted" => true,
                _ => false,
            },
            None => false,
        },
        None => false,
    };

    gobal_state.bomb_planted.store(planted, Ordering::Relaxed);

    json!({ "status": "ok"})
}

#[launch]
fn rocket() -> _ {
    let state: State = State::new();
    let state_clone = state.clone();
    let addr = "192.168.0.59:21324";

    thread::spawn(move || {
        led::led_loop(30,addr,36, state_clone);
    });

    let figment = rocket::figment::Figment::from(rocket::Config::default())
        .merge(("log_level", "critical"));

    rocket::custom(figment)
        .manage(state)
        .mount("/", routes![gsi])
}
